@@ -3,9 +3,6 @@ from .Topic import *
 from .Core.List import *
 from .Core.Terminal import *
 
-#for debug
-from Fetcher import *
-
 BS4_SETTING = 'html.parser'
 
 class Scraper:
@@ -61,7 +58,6 @@ class Scraper:
             data.decompose()
     
         # return data by retrieving the tag content
-        Terminal.put("✅ Script and style clean successful")
         return ' '.join(self._soup.stripped_strings)
 
     def __str__(self):
